# pYPK0_PGItp_ScXKS1_FBA1tp

# Step 1 Prepare vector

Linearize pYPKpw with EcoRV resulting in the linearized vector.

# Step 2 PCR of first tp

Carry out a PCR with primers 577, 567 and template pYPKa_Z_PGItp resulting in the PCR product 1231bp_PCR_prod

    5GTTCTGATCCTCGAGCATCTTAAGAATTC...CTCACTAGTGACCTGCAGCCGAC3
                                     ||||||||||||||||||||||| tm 59.0 (dbd) 70.7
                                    3gagtgatcactggacgtcggcTG5
    5gttctgatcctcgagcatcttaagaattc3
     ||||||||||||||||||||||||||||| tm 56.1 (dbd) 69.4
    3CAAGACTAGGAGCTCGTAGAATTCTTAAG...GAGTGATCACTGGACGTCGGCTG5

    Taq (rate 30 nt/s)
    Three-step|         30 cycles     |      |SantaLucia 1998
    94.0°C    |94.0°C                 |      |SaltC 50mM
    __________|_____          72.0°C  |72.0°C|
    04min00s  |30s  \         ________|______|
              |      \ 56.0°C/ 0min36s|10min |
              |       \_____/         |      |
              |         30s           |      |4-8°C

    Pfu-Sso7d (rate 15s/kb)
    Two-step|    30 cycles |      |Breslauer1986,SantaLucia1998
    98.0°C  |98.0C         |      |SaltC 50mM
    _____ __|_____         |      |Primer1C 1000µM
    00min30s|10s  \  72.0°C|72.0°C|Primer2C <bound method Amplicon.rc of Amplicon(1231)>µM
            |      \_______|______|
            |       0min18s|10min |4-8°C

# Step 3 Gene PCR

Carry out a PCR with primers 468, 467 and template pYPKa_A_ScXKS1 resulting in the PCR product 1892bp_PCR_prod

    5GTCGAGGAACGCCAGGTTGCCCACT...TCTGTGCAGACAAACGCATCAGGAT3
                                 ||||||||||||||||||||||||| tm 59.0 (dbd) 73.8
                                3agacacgtctgtttgcgtagtcctaAATTTA5
    5gtcgaggaacgccaggttgcccact3
     ||||||||||||||||||||||||| tm 64.8 (dbd) 79.7
    3CAGCTCCTTGCGGTCCAACGGGTGA...AGACACGTCTGTTTGCGTAGTCCTA5

    Taq (rate 30 nt/s)
    Three-step|         30 cycles     |      |SantaLucia 1998
    94.0°C    |94.0°C                 |      |SaltC 50mM
    __________|_____          72.0°C  |72.0°C|
    04min00s  |30s  \         ________|______|
              |      \ 57.0°C/ 0min56s|10min |
              |       \_____/         |      |
              |         30s           |      |4-8°C

    Pfu-Sso7d (rate 15s/kb)
    Two-step|    30 cycles |      |Breslauer1986,SantaLucia1998
    98.0°C  |98.0C         |      |SaltC 50mM
    _____ __|_____         |      |Primer1C 1000µM
    00min30s|10s  \  72.0°C|72.0°C|Primer2C <bound method Amplicon.rc of Amplicon(1892)>µM
            |      \_______|______|
            |       0min28s|10min |4-8°C

# Step 4 PCR of last tp

Carry out a PCR with primers 568, 578 and template pYPKa_E_FBA1tp resulting in the PCR product 969bp_PCR_prod

    5GTGCCATCTGTGCAGACAAACG...ACTTATGAATGTGGCAATGAGACAAGAAC3
                              ||||||||||||||||||||||||||||| tm 56.5 (dbd) 69.5
                             3tgaatacttacaccgttactctgttcttg5
    5GTGCcatctgtgcagacaaacg3
     |||||||||||||||||||||| tm 57.1 (dbd) 71.5
    3CACGGTAGACACGTCTGTTTGC...TGAATACTTACACCGTTACTCTGTTCTTG5

    Taq (rate 30 nt/s)
    Three-step|         30 cycles     |      |SantaLucia 1998
    94.0°C    |94.0°C                 |      |SaltC 50mM
    __________|_____          72.0°C  |72.0°C|
    04min00s  |30s  \         ________|______|
              |      \ 56.0°C/ 0min29s|10min |
              |       \_____/         |      |
              |         30s           |      |4-8°C

    Pfu-Sso7d (rate 15s/kb)
    Two-step|    30 cycles |      |Breslauer1986,SantaLucia1998
    98.0°C  |98.0C         |      |SaltC 50mM
    _____ __|_____         |      |Primer1C 1000µM
    00min30s|10s  \  72.0°C|72.0°C|Primer2C <bound method Amplicon.rc of Amplicon(969)>µM
            |      \_______|______|
            |       0min14s|10min |4-8°C

# Step 5 Yeast transformation

Mix the four linear DNA fragments and transform a Saccharomyces cerevisiae ura3 mutant with the mixture. The fragments will be assembled by in-vivo homologous recombination:

     -|pYPKpw|124
    |         \/
    |         /\
    |         124|1231bp_PCR_prod|50
    |                             \/
    |                             /\
    |                             50|1892bp_PCR_prod|37
    |                                                \/
    |                                                /\
    |                                                37|969bp_PCR_prod|242
    |                                                                  \/
    |                                                                  /\
    |                                                                  242-
    |                                                                     |
     ---------------------------------------------------------------------

# Step 6 Diagnostic PCR confirmation

## First tp and gene

PCR using primers 577 & 467

PCR products (bp)

> Correct : 3073
> Missing first tp : 2060
> Missing gene : 1268
> Missing both : 255

## Gene and last tp

PCR using primers 468 & 578

PCR products (bp)

> Correct : 2824
> Missing gene : 1019
> Missing last tp : 2181
> Missing both : 376